OC.L10N.register(
    "viewer",
    {
    "Viewer" : "ビューア",
    "Simple file viewer with slideshow for media" : "メディアスライドショー用の簡易ファイルビューア",
    "Error loading {name}" : "[名前]の読み込みエラー",
    "Your browser does not support the video tag." : "あなたのブラウザーはvideoタグをサポートしていません。",
    "View" : "表示",
    "Share" : "共有"
},
"nplurals=1; plural=0;");
